---
slug: /access-control-overview
---

# Overview

Access control prevents unauthorized users from accessing database data by designing permissions and features. In terms of permission design, seekdb ensures account security by setting different verification strategies for users and roles. In terms of feature design, seekdb ensures secure database access by setting up allowlists.

## Permission Management

For more information, see:

* [Overview](200.user-and-permission/50.user-and-permission-overview.md)

* [Permission Classification](200.user-and-permission/100.permission-classification.md)

## Network Security Access Control

seekdb provides allowlist strategies to implement network security access control. You can use the tenant allowlist feature to specify which clients are allowed to access seekdb.

For more information about how to implement network security access control by setting up allowlists, see [Network Security Access Control](../300.access-control/300.network-security-access-control.md).